@@ -174,14 +174,17 @@ class SalePromotion(
 
     @classmethod
     def _promotions_domain(cls, sale):
+        pool = Pool()
+        Date = pool.get('ir.date')
+        sale_date = sale.sale_date or Date.today()
         return [
             ['OR',
-                ('start_date', '<=', sale.sale_date),
+                ('start_date', '<=', sale_date),
                 ('start_date', '=', None),
                 ],
             ['OR',
                 ('end_date', '=', None),
-                ('end_date', '>=', sale.sale_date),
+                ('end_date', '>=', sale_date),
                 ],
             ['OR',
                 ('price_list', '=', None),
